# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import Any, Optional

from bungio.models import (
    ContentItemPublicContract,
    ContentTypeDescription,
    NewsArticleRssResponse,
    SearchResultOfContentItemPublicContract,
)
from bungio.models.auth import AuthData
from bungio.models.base import ClientMixin, custom_define


@custom_define()
class ContentRouteInterface(ClientMixin):
    async def get_content_type(self, type: str, auth: Optional[AuthData] = None) -> ContentTypeDescription:
        """
        Gets an object describing a particular variant of content.

        Args:
            type:
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_content_type(type=type, auth=auth)
        return await ContentTypeDescription.from_dict(data=response, client=self._client, type=type, auth=auth)

    async def get_content_by_id(
        self, id: int, locale: str, head: Optional[bool] = None, auth: Optional[AuthData] = None
    ) -> ContentItemPublicContract:
        """
        Returns a content item referenced by id

        Args:
            id:
            locale:
            head: false
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_content_by_id(
            id=id, locale=locale, head=head if head else None, auth=auth
        )
        return await ContentItemPublicContract.from_dict(
            data=response, client=self._client, id=id, locale=locale, head=head, auth=auth
        )

    async def get_content_by_tag_and_type(
        self, locale: str, tag: str, type: str, head: Optional[bool] = None, auth: Optional[AuthData] = None
    ) -> ContentItemPublicContract:
        """
        Returns the newest item that matches a given tag and Content Type.

        Args:
            locale:
            tag:
            type:
            head: Not used.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.get_content_by_tag_and_type(
            locale=locale, tag=tag, type=type, head=head if head else None, auth=auth
        )
        return await ContentItemPublicContract.from_dict(
            data=response, client=self._client, locale=locale, tag=tag, type=type, head=head, auth=auth
        )

    async def search_content_with_text(
        self,
        locale: str,
        ctype: Optional[str] = None,
        currentpage: Optional[int] = None,
        head: Optional[bool] = None,
        searchtext: Optional[str] = None,
        source: Optional[str] = None,
        tag: Optional[str] = None,
        auth: Optional[AuthData] = None,
    ) -> SearchResultOfContentItemPublicContract:
        """
        Gets content based on querystring information passed in. Provides basic search and text search capabilities.

        Args:
            locale:
            ctype: Content type tag: Help, News, etc. Supply multiple ctypes separated by space.
            currentpage: Page number for the search results, starting with page 1.
            head: Not used.
            searchtext: Word or phrase for the search.
            source: For analytics, hint at the part of the app that triggered the search. Optional.
            tag: Tag used on the content to be searched.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.search_content_with_text(
            locale=locale,
            ctype=ctype if ctype else None,
            currentpage=currentpage if currentpage else None,
            head=head if head else None,
            searchtext=searchtext if searchtext else None,
            source=source if source else None,
            tag=tag if tag else None,
            auth=auth,
        )
        return await SearchResultOfContentItemPublicContract.from_dict(
            data=response,
            client=self._client,
            locale=locale,
            ctype=ctype,
            currentpage=currentpage,
            head=head,
            searchtext=searchtext,
            source=source,
            tag=tag,
            auth=auth,
        )

    async def search_content_by_tag_and_type(
        self,
        locale: str,
        tag: str,
        type: str,
        currentpage: Optional[int] = None,
        head: Optional[bool] = None,
        itemsperpage: Optional[int] = None,
        auth: Optional[AuthData] = None,
    ) -> SearchResultOfContentItemPublicContract:
        """
        Searches for Content Items that match the given Tag and Content Type.

        Args:
            locale:
            tag:
            type:
            currentpage: Page number for the search results starting with page 1.
            head: Not used.
            itemsperpage: Not used.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.search_content_by_tag_and_type(
            locale=locale,
            tag=tag,
            type=type,
            currentpage=currentpage if currentpage else None,
            head=head if head else None,
            itemsperpage=itemsperpage if itemsperpage else None,
            auth=auth,
        )
        return await SearchResultOfContentItemPublicContract.from_dict(
            data=response,
            client=self._client,
            locale=locale,
            tag=tag,
            type=type,
            currentpage=currentpage,
            head=head,
            itemsperpage=itemsperpage,
            auth=auth,
        )

    async def search_help_articles(self, searchtext: str, size: str, auth: Optional[AuthData] = None) -> Any:
        """
        Search for Help Articles.

        Args:
            searchtext:
            size:
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.search_help_articles(searchtext=searchtext, size=size, auth=auth)
        return response["Response"]

    async def rss_news_articles(self, page_token: str, auth: Optional[AuthData] = None) -> NewsArticleRssResponse:
        """
        Returns a JSON string response that is the RSS feed for news articles.

        Args:
            page_token: Zero-based pagination token for paging through result sets.
            auth: Authentication information. Required when users with a private profile are queried, or when Bungie feels like it

        Returns:
            The model which is returned by bungie. [General endpoint information.](https://bungie-net.github.io/multi/index.html)
        """

        response = await self._client.http.rss_news_articles(page_token=page_token, auth=auth)
        return await NewsArticleRssResponse.from_dict(
            data=response, client=self._client, page_token=page_token, auth=auth
        )



from bungio.models.bungie.applications import (
    ApiUsage,
    Application,
    ApplicationDeveloper,
    ApplicationScopes,
    ApplicationStatus,
    Datapoint,
    DeveloperRole,
    Series,
)
from bungio.models.bungie.common.models import (
    CoreSetting,
    CoreSettingsConfiguration,
    CoreSystem,
    Destiny2CoreSettings,
)
from bungio.models.bungie.components import ComponentPrivacySetting, ComponentResponse
from bungio.models.bungie.config import GroupTheme, UserTheme
from bungio.models.bungie.config.clanbanner import ClanBannerDecal
from bungio.models.bungie.content import (
    CommentSummary,
    ContentItemPublicContract,
    ContentRepresentation,
    NewsArticleRssItem,
    NewsArticleRssResponse,
)
from bungio.models.bungie.content.models import (
    ContentPreview,
    ContentPropertyDataTypeEnum,
    ContentTypeDefaultValue,
    ContentTypeDescription,
    ContentTypeProperty,
    ContentTypePropertySection,
    TagMetadataDefinition,
    TagMetadataItem,
)
from bungio.models.bungie.dates import DateRange
from bungio.models.bungie.destiny import (
    ActivityGraphNodeHighlightType,
    BucketCategory,
    BucketScope,
    DamageType,
    DestinyActivity,
    DestinyActivityDifficultyTier,
    DestinyActivityModeCategory,
    DestinyActivityNavPointType,
    DestinyAmmunitionType,
    DestinyBreakerType,
    DestinyClass,
    DestinyCollectibleState,
    DestinyComponentType,
    DestinyEnergyType,
    DestinyEquipItemResult,
    DestinyEquipItemResults,
    DestinyGamePrivacySetting,
    DestinyGameVersions,
    DestinyGatingScope,
    DestinyGender,
    DestinyGraphNodeState,
    DestinyItemQuantity,
    DestinyItemSortType,
    DestinyItemSubType,
    DestinyItemType,
    DestinyJoinClosedReasons,
    DestinyObjectiveGrantStyle,
    DestinyObjectiveUiStyle,
    DestinyPartyMemberStates,
    DestinyPresentationDisplayStyle,
    DestinyPresentationNodeState,
    DestinyPresentationNodeType,
    DestinyPresentationScreenStyle,
    DestinyProgression,
    DestinyProgressionResetEntry,
    DestinyProgressionRewardItemAcquisitionBehavior,
    DestinyProgressionRewardItemState,
    DestinyProgressionScope,
    DestinyProgressionStepDisplayEffect,
    DestinyRace,
    DestinyRecordState,
    DestinyRecordToastStyle,
    DestinyRecordValueStyle,
    DestinyScope,
    DestinySocketCategoryStyle,
    DestinySocketVisibility,
    DestinyStat,
    DestinyStatAggregationType,
    DestinyStatCategory,
    DestinyTalentNode,
    DestinyTalentNodeStatBlock,
    DestinyTalentNodeState,
    DestinyUnlockStatus,
    DestinyUnlockValueUIStyle,
    DestinyVendorFilter,
    DestinyVendorInteractionRewardSelection,
    DestinyVendorItemRefundPolicy,
    DestinyVendorItemState,
    DestinyVendorProgressionType,
    DestinyVendorReplyType,
    DyeReference,
    EquipFailureReason,
    EquippingItemBlockAttributes,
    ItemBindStatus,
    ItemLocation,
    ItemPerkVisibility,
    ItemState,
    PlugAvailabilityMode,
    PlugUiStyles,
    SocketPlugSources,
    SocketTypeActionType,
    SpecialItemType,
    TierType,
    TransferStatuses,
    VendorDisplayCategorySortOrder,
    VendorInteractionType,
    VendorItemStatus,
)
from bungio.models.bungie.destiny.activities import DestinyPublicActivityStatus
from bungio.models.bungie.destiny.advanced import (
    AwaAuthorizationResult,
    AwaInitializeResponse,
    AwaPermissionRequested,
    AwaResponseReason,
    AwaType,
    AwaUserResponse,
    AwaUserSelection,
)
from bungio.models.bungie.destiny.artifacts import (
    DestinyArtifactCharacterScoped,
    DestinyArtifactProfileScoped,
    DestinyArtifactTier,
    DestinyArtifactTierItem,
)
from bungio.models.bungie.destiny.challenges import DestinyChallengeStatus
from bungio.models.bungie.destiny.character import (
    DestinyCharacterCustomization,
    DestinyCharacterPeerView,
    DestinyItemPeerView,
)
from bungio.models.bungie.destiny.components.collectibles import (
    DestinyCollectibleComponent,
    DestinyCollectiblesComponent,
    DestinyProfileCollectiblesComponent,
)
from bungio.models.bungie.destiny.components.craftables import (
    DestinyCraftableComponent,
    DestinyCraftablesComponent,
    DestinyCraftableSocketComponent,
    DestinyCraftableSocketPlugComponent,
)
from bungio.models.bungie.destiny.components.inventory import (
    DestinyCurrenciesComponent,
    DestinyPlatformSilverComponent,
)
from bungio.models.bungie.destiny.components.items import (
    DestinyItemPlugComponent,
    DestinyItemPlugObjectivesComponent,
    DestinyItemReusablePlugsComponent,
)
from bungio.models.bungie.destiny.components.kiosks import (
    DestinyKioskItem,
    DestinyKiosksComponent,
)
from bungio.models.bungie.destiny.components.metrics import (
    DestinyMetricComponent,
    DestinyMetricsComponent,
)
from bungio.models.bungie.destiny.components.plugsets import DestinyPlugSetsComponent
from bungio.models.bungie.destiny.components.presentation import (
    DestinyPresentationNodeComponent,
    DestinyPresentationNodesComponent,
)
from bungio.models.bungie.destiny.components.profiles import (
    DestinyProfileProgressionComponent,
    DestinyProfileTransitoryComponent,
    DestinyProfileTransitoryCurrentActivity,
    DestinyProfileTransitoryJoinability,
    DestinyProfileTransitoryPartyMember,
    DestinyProfileTransitoryTrackingEntry,
)
from bungio.models.bungie.destiny.components.records import (
    DestinyCharacterRecordsComponent,
    DestinyProfileRecordsComponent,
    DestinyRecordComponent,
    DestinyRecordsComponent,
)
from bungio.models.bungie.destiny.components.stringvariables import (
    DestinyStringVariablesComponent,
)
from bungio.models.bungie.destiny.components.vendors import (
    DestinyPublicVendorComponent,
    DestinyPublicVendorSaleItemComponent,
    DestinyVendorBaseComponent,
    DestinyVendorGroup,
    DestinyVendorGroupComponent,
    DestinyVendorSaleItemBaseComponent,
)
from bungio.models.bungie.destiny.config import (
    DestinyManifest,
    GearAssetDataBaseDefinition,
    ImagePyramidEntry,
)
from bungio.models.bungie.destiny.constants import DestinyEnvironmentLocationMapping
from bungio.models.bungie.destiny.definitions import (
    DestinyActivityChallengeDefinition,
    DestinyActivityDefinition,
    DestinyActivityGraphListEntryDefinition,
    DestinyActivityGuidedBlockDefinition,
    DestinyActivityInsertionPointDefinition,
    DestinyActivityLoadoutRequirement,
    DestinyActivityLoadoutRequirementSet,
    DestinyActivityMatchmakingBlockDefinition,
    DestinyActivityModeDefinition,
    DestinyActivityModifierReferenceDefinition,
    DestinyActivityPlaylistItemDefinition,
    DestinyActivityRewardDefinition,
    DestinyActivityTypeDefinition,
    DestinyActivityUnlockStringDefinition,
    DestinyArrangementRegionFilterDefinition,
    DestinyArtDyeReference,
    DestinyBubbleDefinition,
    DestinyClassDefinition,
    DestinyDamageTypeDefinition,
    DestinyDefinition,
    DestinyDestinationBubbleSettingDefinition,
    DestinyDestinationDefinition,
    DestinyDisplayCategoryDefinition,
    DestinyEntitySearchResult,
    DestinyEntitySearchResultItem,
    DestinyEquipmentSlotDefinition,
    DestinyEquippingBlockDefinition,
    DestinyFactionDefinition,
    DestinyFactionVendorDefinition,
    DestinyGearArtArrangementReference,
    DestinyGenderDefinition,
    DestinyInventoryBucketDefinition,
    DestinyInventoryItemDefinition,
    DestinyInventoryItemStatDefinition,
    DestinyItemActionBlockDefinition,
    DestinyItemActionRequiredItemDefinition,
    DestinyItemCategoryDefinition,
    DestinyItemCraftingBlockBonusPlugDefinition,
    DestinyItemCraftingBlockDefinition,
    DestinyItemCreationEntryLevelDefinition,
    DestinyItemGearsetBlockDefinition,
    DestinyItemIntrinsicSocketEntryDefinition,
    DestinyItemInventoryBlockDefinition,
    DestinyItemInvestmentStatDefinition,
    DestinyItemMetricBlockDefinition,
    DestinyItemObjectiveBlockDefinition,
    DestinyItemPerkEntryDefinition,
    DestinyItemPreviewBlockDefinition,
    DestinyItemQualityBlockDefinition,
    DestinyItemSackBlockDefinition,
    DestinyItemSetBlockDefinition,
    DestinyItemSetBlockEntryDefinition,
    DestinyItemSocketBlockDefinition,
    DestinyItemSocketCategoryDefinition,
    DestinyItemSocketEntryDefinition,
    DestinyItemSocketEntryPlugItemDefinition,
    DestinyItemSocketEntryPlugItemRandomizedDefinition,
    DestinyItemSourceBlockDefinition,
    DestinyItemStatBlockDefinition,
    DestinyItemSummaryBlockDefinition,
    DestinyItemTalentGridBlockDefinition,
    DestinyItemTooltipNotification,
    DestinyItemTranslationBlockDefinition,
    DestinyItemValueBlockDefinition,
    DestinyItemVendorSourceReference,
    DestinyItemVersionDefinition,
    DestinyLocationDefinition,
    DestinyLocationReleaseDefinition,
    DestinyMaterialRequirement,
    DestinyMaterialRequirementSetDefinition,
    DestinyMedalTierDefinition,
    DestinyNodeActivationRequirement,
    DestinyNodeSocketReplaceResponse,
    DestinyNodeStepDefinition,
    DestinyObjectiveDefinition,
    DestinyObjectiveDisplayProperties,
    DestinyObjectivePerkEntryDefinition,
    DestinyObjectiveStatEntryDefinition,
    DestinyPlaceDefinition,
    DestinyPlugItemCraftingRequirements,
    DestinyPlugItemCraftingUnlockRequirement,
    DestinyProgressionDefinition,
    DestinyProgressionDisplayPropertiesDefinition,
    DestinyProgressionMappingDefinition,
    DestinyProgressionRewardDefinition,
    DestinyProgressionRewardItemQuantity,
    DestinyProgressionStepDefinition,
    DestinyRaceDefinition,
    DestinyRewardSourceCategory,
    DestinyRewardSourceDefinition,
    DestinySandboxPatternDefinition,
    DestinySandboxPerkDefinition,
    DestinyStatDefinition,
    DestinyStatDisplayDefinition,
    DestinyStatGroupDefinition,
    DestinyStatOverrideDefinition,
    DestinyTalentExclusiveGroup,
    DestinyTalentGridDefinition,
    DestinyTalentNodeCategory,
    DestinyTalentNodeDefinition,
    DestinyTalentNodeExclusiveSetDefinition,
    DestinyTalentNodeStepDamageTypes,
    DestinyTalentNodeStepGroups,
    DestinyTalentNodeStepGuardianAttributes,
    DestinyTalentNodeStepImpactEffects,
    DestinyTalentNodeStepLightAbilities,
    DestinyTalentNodeStepWeaponPerformances,
    DestinyUnlockDefinition,
    DestinyUnlockExpressionDefinition,
    DestinyUnlockValueDefinition,
    DestinyVendorAcceptedItemDefinition,
    DestinyVendorActionDefinition,
    DestinyVendorCategoryEntryDefinition,
    DestinyVendorCategoryOverlayDefinition,
    DestinyVendorDefinition,
    DestinyVendorDisplayPropertiesDefinition,
    DestinyVendorGroupDefinition,
    DestinyVendorGroupReference,
    DestinyVendorInteractionDefinition,
    DestinyVendorInteractionReplyDefinition,
    DestinyVendorInteractionSackEntryDefinition,
    DestinyVendorInventoryFlyoutBucketDefinition,
    DestinyVendorInventoryFlyoutDefinition,
    DestinyVendorItemDefinition,
    DestinyVendorItemQuantity,
    DestinyVendorItemSocketOverride,
    DestinyVendorRequirementDisplayEntryDefinition,
    DestinyVendorSaleItemActionBlockDefinition,
    DestinyVendorServiceDefinition,
)
from bungio.models.bungie.destiny.definitions.activitymodifiers import (
    DestinyActivityModifierDefinition,
)
from bungio.models.bungie.destiny.definitions.animations import (
    DestinyAnimationReference,
)
from bungio.models.bungie.destiny.definitions.artifacts import (
    DestinyArtifactDefinition,
    DestinyArtifactTierDefinition,
    DestinyArtifactTierItemDefinition,
)
from bungio.models.bungie.destiny.definitions.breakertypes import (
    DestinyBreakerTypeDefinition,
)
from bungio.models.bungie.destiny.definitions.checklists import (
    DestinyChecklistDefinition,
    DestinyChecklistEntryDefinition,
)
from bungio.models.bungie.destiny.definitions.collectibles import (
    DestinyCollectibleAcquisitionBlock,
    DestinyCollectibleDefinition,
    DestinyCollectibleStateBlock,
)
from bungio.models.bungie.destiny.definitions.common import (
    DestinyDisplayPropertiesDefinition,
    DestinyIconSequenceDefinition,
    DestinyPositionDefinition,
)
from bungio.models.bungie.destiny.definitions.director import (
    DestinyActivityGraphArtElementDefinition,
    DestinyActivityGraphConnectionDefinition,
    DestinyActivityGraphDefinition,
    DestinyActivityGraphDisplayObjectiveDefinition,
    DestinyActivityGraphDisplayProgressionDefinition,
    DestinyActivityGraphNodeActivityDefinition,
    DestinyActivityGraphNodeDefinition,
    DestinyActivityGraphNodeFeaturingStateDefinition,
    DestinyActivityGraphNodeStateEntry,
    DestinyLinkedGraphDefinition,
    DestinyLinkedGraphEntryDefinition,
)
from bungio.models.bungie.destiny.definitions.energytypes import (
    DestinyEnergyTypeDefinition,
)
from bungio.models.bungie.destiny.definitions.items import (
    DestinyDerivedItemCategoryDefinition,
    DestinyDerivedItemDefinition,
    DestinyEnergyCapacityEntry,
    DestinyEnergyCostEntry,
    DestinyItemPlugDefinition,
    DestinyItemTierTypeDefinition,
    DestinyItemTierTypeInfusionBlock,
    DestinyParentItemOverride,
    DestinyPlugRuleDefinition,
)
from bungio.models.bungie.destiny.definitions.lore import DestinyLoreDefinition
from bungio.models.bungie.destiny.definitions.metrics import DestinyMetricDefinition
from bungio.models.bungie.destiny.definitions.milestones import (
    DestinyMilestoneActivityDefinition,
    DestinyMilestoneActivityVariantDefinition,
    DestinyMilestoneChallengeActivityDefinition,
    DestinyMilestoneChallengeActivityGraphNodeEntry,
    DestinyMilestoneChallengeActivityPhase,
    DestinyMilestoneChallengeDefinition,
    DestinyMilestoneDefinition,
    DestinyMilestoneDisplayPreference,
    DestinyMilestoneQuestDefinition,
    DestinyMilestoneQuestRewardItem,
    DestinyMilestoneQuestRewardsDefinition,
    DestinyMilestoneRewardCategoryDefinition,
    DestinyMilestoneRewardEntryDefinition,
    DestinyMilestoneType,
    DestinyMilestoneValueDefinition,
    DestinyMilestoneVendorDefinition,
)
from bungio.models.bungie.destiny.definitions.powercaps import DestinyPowerCapDefinition
from bungio.models.bungie.destiny.definitions.presentation import (
    DestinyPresentationChildBlock,
    DestinyPresentationNodeBaseDefinition,
    DestinyPresentationNodeChildEntry,
    DestinyPresentationNodeChildEntryBase,
    DestinyPresentationNodeChildrenBlock,
    DestinyPresentationNodeCollectibleChildEntry,
    DestinyPresentationNodeCraftableChildEntry,
    DestinyPresentationNodeDefinition,
    DestinyPresentationNodeMetricChildEntry,
    DestinyPresentationNodeRecordChildEntry,
    DestinyPresentationNodeRequirementsBlock,
    DestinyScoredPresentationNodeBaseDefinition,
)
from bungio.models.bungie.destiny.definitions.progression import (
    DestinyProgressionLevelRequirementDefinition,
)
from bungio.models.bungie.destiny.definitions.records import (
    DestinyRecordCompletionBlock,
    DestinyRecordDefinition,
    DestinyRecordExpirationBlock,
    DestinyRecordIntervalBlock,
    DestinyRecordIntervalObjective,
    DestinyRecordIntervalRewards,
    DestinyRecordTitleBlock,
    SchemaRecordStateBlock,
)
from bungio.models.bungie.destiny.definitions.reporting import (
    DestinyReportReasonCategoryDefinition,
    DestinyReportReasonDefinition,
)
from bungio.models.bungie.destiny.definitions.seasons import (
    DestinyEventCardDefinition,
    DestinyEventCardImages,
    DestinySeasonDefinition,
    DestinySeasonPassDefinition,
    DestinySeasonPreviewDefinition,
    DestinySeasonPreviewImageDefinition,
)
from bungio.models.bungie.destiny.definitions.sockets import (
    DestinyInsertPlugActionDefinition,
    DestinyPlugSetDefinition,
    DestinyPlugWhitelistEntryDefinition,
    DestinySocketCategoryDefinition,
    DestinySocketTypeDefinition,
    DestinySocketTypeScalarMaterialRequirementEntry,
)
from bungio.models.bungie.destiny.definitions.sources import DestinyItemSourceDefinition
from bungio.models.bungie.destiny.definitions.traits import (
    DestinyTraitCategoryDefinition,
    DestinyTraitDefinition,
)
from bungio.models.bungie.destiny.definitions.vendors import (
    DestinyVendorLocationDefinition,
)
from bungio.models.bungie.destiny.entities.characters import (
    DestinyCharacterActivitiesComponent,
    DestinyCharacterComponent,
    DestinyCharacterProgressionComponent,
    DestinyCharacterRenderComponent,
)
from bungio.models.bungie.destiny.entities.inventory import DestinyInventoryComponent
from bungio.models.bungie.destiny.entities.items import (
    DestinyItemComponent,
    DestinyItemInstanceComponent,
    DestinyItemInstanceEnergy,
    DestinyItemObjectivesComponent,
    DestinyItemPerksComponent,
    DestinyItemRenderComponent,
    DestinyItemSocketsComponent,
    DestinyItemSocketState,
    DestinyItemStatsComponent,
    DestinyItemTalentGridComponent,
)
from bungio.models.bungie.destiny.entities.profiles import (
    DestinyProfileComponent,
    DestinyVendorReceiptsComponent,
)
from bungio.models.bungie.destiny.entities.vendors import (
    DestinyVendorCategoriesComponent,
    DestinyVendorCategory,
    DestinyVendorComponent,
    DestinyVendorSaleItemComponent,
)
from bungio.models.bungie.destiny.historicalstats import (
    DestinyActivityHistoryResults,
    DestinyAggregateActivityResults,
    DestinyAggregateActivityStats,
    DestinyClanAggregateStat,
    DestinyHistoricalStatsAccountResult,
    DestinyHistoricalStatsActivity,
    DestinyHistoricalStatsByPeriod,
    DestinyHistoricalStatsPerCharacter,
    DestinyHistoricalStatsValue,
    DestinyHistoricalStatsValuePair,
    DestinyHistoricalStatsWithMerged,
    DestinyHistoricalWeaponStats,
    DestinyHistoricalWeaponStatsData,
    DestinyLeaderboard,
    DestinyLeaderboardEntry,
    DestinyLeaderboardResults,
    DestinyPlayer,
    DestinyPostGameCarnageReportData,
    DestinyPostGameCarnageReportEntry,
    DestinyPostGameCarnageReportExtendedData,
    DestinyPostGameCarnageReportTeamEntry,
)
from bungio.models.bungie.destiny.historicalstats.definitions import (
    DestinyActivityModeType,
    DestinyHistoricalStatsDefinition,
    DestinyStatsCategoryType,
    DestinyStatsGroupType,
    DestinyStatsMergeMethod,
    PeriodType,
    UnitType,
)
from bungio.models.bungie.destiny.milestones import (
    DestinyMilestone,
    DestinyMilestoneActivity,
    DestinyMilestoneActivityCompletionStatus,
    DestinyMilestoneActivityPhase,
    DestinyMilestoneActivityVariant,
    DestinyMilestoneChallengeActivity,
    DestinyMilestoneContent,
    DestinyMilestoneContentItemCategory,
    DestinyMilestoneQuest,
    DestinyMilestoneRewardCategory,
    DestinyMilestoneRewardEntry,
    DestinyMilestoneVendor,
    DestinyPublicMilestone,
    DestinyPublicMilestoneActivity,
    DestinyPublicMilestoneActivityVariant,
    DestinyPublicMilestoneChallenge,
    DestinyPublicMilestoneChallengeActivity,
    DestinyPublicMilestoneQuest,
    DestinyPublicMilestoneVendor,
)
from bungio.models.bungie.destiny.misc import DestinyColor
from bungio.models.bungie.destiny.perks import DestinyPerkReference
from bungio.models.bungie.destiny.progression import DestinyFactionProgression
from bungio.models.bungie.destiny.quests import (
    DestinyObjectiveProgress,
    DestinyQuestStatus,
)
from bungio.models.bungie.destiny.reporting.requests import (
    DestinyReportOffensePgcrRequest,
)
from bungio.models.bungie.destiny.requests import DestinyItemTransferRequest
from bungio.models.bungie.destiny.requests.actions import (
    DestinyActionRequest,
    DestinyCharacterActionRequest,
    DestinyInsertPlugsActionRequest,
    DestinyInsertPlugsFreeActionRequest,
    DestinyInsertPlugsRequestEntry,
    DestinyItemActionRequest,
    DestinyItemSetActionRequest,
    DestinyItemStateRequest,
    DestinyPostmasterTransferRequest,
    DestinySocketArrayType,
)
from bungio.models.bungie.destiny.responses import (
    DestinyCharacterResponse,
    DestinyCollectibleNodeDetailResponse,
    DestinyErrorProfile,
    DestinyItemChangeResponse,
    DestinyItemResponse,
    DestinyLinkedProfilesResponse,
    DestinyProfileResponse,
    DestinyProfileUserInfoCard,
    DestinyPublicVendorsResponse,
    DestinyVendorResponse,
    DestinyVendorsResponse,
    InventoryChangedResponse,
    PersonalDestinyVendorSaleItemSetComponent,
    PublicDestinyVendorSaleItemSetComponent,
)
from bungio.models.bungie.destiny.sockets import DestinyItemPlug, DestinyItemPlugBase
from bungio.models.bungie.destiny.vendors import DestinyVendorReceipt
from bungio.models.bungie.entities import EntityActionResult
from bungio.models.bungie.exceptions import PlatformErrorCodes
from bungio.models.bungie.fireteam import (
    FireteamDateRange,
    FireteamMember,
    FireteamPlatform,
    FireteamPlatformInviteResult,
    FireteamPublicSearchOption,
    FireteamResponse,
    FireteamSlotSearch,
    FireteamSummary,
    FireteamUserInfoCard,
)
from bungio.models.bungie.forum import (
    CommunityContentSortMode,
    ForumMediaType,
    ForumPostPopularity,
    ForumPostSortEnum,
    ForumRecruitmentDetail,
    ForumRecruitmentIntensityLabel,
    ForumRecruitmentToneLabel,
    ForumTopicsCategoryFiltersEnum,
    ForumTopicsQuickDateEnum,
    ForumTopicsSortEnum,
    PollResponse,
    PollResult,
    PostResponse,
    PostSearchResponse,
)
from bungio.models.bungie.forums import ForumFlagsEnum, ForumPostCategoryEnums
from bungio.models.bungie.groupsv2 import (
    Capabilities,
    ChatSecuritySetting,
    ClanBanner,
    GetGroupsForMemberResponse,
    GroupAllianceStatus,
    GroupApplicationListRequest,
    GroupApplicationRequest,
    GroupApplicationResolveState,
    GroupApplicationResponse,
    GroupBan,
    GroupBanRequest,
    GroupDateRange,
    GroupEditAction,
    GroupFeatures,
    GroupHomepage,
    GroupMember,
    GroupMemberApplication,
    GroupMemberCountFilter,
    GroupMemberLeaveResult,
    GroupMembership,
    GroupMembershipBase,
    GroupMembershipSearchResponse,
    GroupNameSearchRequest,
    GroupOptionalConversation,
    GroupOptionalConversationAddRequest,
    GroupOptionalConversationEditRequest,
    GroupOptionsEditAction,
    GroupPostPublicity,
    GroupPotentialMember,
    GroupPotentialMembership,
    GroupPotentialMembershipSearchResponse,
    GroupPotentialMemberStatus,
    GroupResponse,
    GroupSearchResponse,
    GroupsForMemberFilter,
    GroupSortBy,
    GroupType,
    GroupUserBase,
    GroupUserInfoCard,
    GroupV2,
    GroupV2Card,
    GroupV2ClanInfo,
    GroupV2ClanInfoAndInvestment,
    HostGuidedGamesPermissionLevel,
    MembershipOption,
    RuntimeGroupMemberType,
)
from bungio.models.bungie.ignores import IgnoreLength, IgnoreResponse, IgnoreStatus
from bungio.models.bungie.interpolation import (
    InterpolationPoint,
    InterpolationPointFloat,
)
from bungio.models.bungie.links import HyperlinkReference
from bungio.models.bungie.misc import (
    BungieCredentialType,
    BungieMembershipType,
    DestinyBaseItemComponentSetOfint32,
    DestinyBaseItemComponentSetOfint64,
    DestinyBaseItemComponentSetOfuint32,
    DestinyItemComponentSetOfint32,
    DestinyItemComponentSetOfint64,
    DestinyItemComponentSetOfuint32,
    DestinyVendorSaleItemSetComponentOfDestinyPublicVendorSaleItemComponent,
    DestinyVendorSaleItemSetComponentOfDestinyVendorSaleItemComponent,
    DictionaryComponentResponseOfint32AndDestinyItemInstanceComponent,
    DictionaryComponentResponseOfint32AndDestinyItemObjectivesComponent,
    DictionaryComponentResponseOfint32AndDestinyItemPerksComponent,
    DictionaryComponentResponseOfint32AndDestinyItemPlugObjectivesComponent,
    DictionaryComponentResponseOfint32AndDestinyItemRenderComponent,
    DictionaryComponentResponseOfint32AndDestinyItemReusablePlugsComponent,
    DictionaryComponentResponseOfint32AndDestinyItemSocketsComponent,
    DictionaryComponentResponseOfint32AndDestinyItemStatsComponent,
    DictionaryComponentResponseOfint32AndDestinyItemTalentGridComponent,
    DictionaryComponentResponseOfint32AndDestinyVendorSaleItemComponent,
    DictionaryComponentResponseOfint64AndDestinyCharacterActivitiesComponent,
    DictionaryComponentResponseOfint64AndDestinyCharacterComponent,
    DictionaryComponentResponseOfint64AndDestinyCharacterProgressionComponent,
    DictionaryComponentResponseOfint64AndDestinyCharacterRecordsComponent,
    DictionaryComponentResponseOfint64AndDestinyCharacterRenderComponent,
    DictionaryComponentResponseOfint64AndDestinyCollectiblesComponent,
    DictionaryComponentResponseOfint64AndDestinyCraftablesComponent,
    DictionaryComponentResponseOfint64AndDestinyCurrenciesComponent,
    DictionaryComponentResponseOfint64AndDestinyInventoryComponent,
    DictionaryComponentResponseOfint64AndDestinyItemInstanceComponent,
    DictionaryComponentResponseOfint64AndDestinyItemObjectivesComponent,
    DictionaryComponentResponseOfint64AndDestinyItemPerksComponent,
    DictionaryComponentResponseOfint64AndDestinyItemPlugObjectivesComponent,
    DictionaryComponentResponseOfint64AndDestinyItemRenderComponent,
    DictionaryComponentResponseOfint64AndDestinyItemReusablePlugsComponent,
    DictionaryComponentResponseOfint64AndDestinyItemSocketsComponent,
    DictionaryComponentResponseOfint64AndDestinyItemStatsComponent,
    DictionaryComponentResponseOfint64AndDestinyItemTalentGridComponent,
    DictionaryComponentResponseOfint64AndDestinyKiosksComponent,
    DictionaryComponentResponseOfint64AndDestinyPlugSetsComponent,
    DictionaryComponentResponseOfint64AndDestinyPresentationNodesComponent,
    DictionaryComponentResponseOfint64AndDestinyStringVariablesComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemInstanceComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemObjectivesComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemPerksComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemPlugComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemPlugObjectivesComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemRenderComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemReusablePlugsComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemSocketsComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemStatsComponent,
    DictionaryComponentResponseOfuint32AndDestinyItemTalentGridComponent,
    DictionaryComponentResponseOfuint32AndDestinyPublicVendorComponent,
    DictionaryComponentResponseOfuint32AndDestinyVendorCategoriesComponent,
    DictionaryComponentResponseOfuint32AndDestinyVendorComponent,
    DictionaryComponentResponseOfuint32AndPersonalDestinyVendorSaleItemSetComponent,
    DictionaryComponentResponseOfuint32AndPublicDestinyVendorSaleItemSetComponent,
    GlobalAlert,
    GlobalAlertLevel,
    GlobalAlertType,
    SearchResultOfContentItemPublicContract,
    SearchResultOfDestinyEntitySearchResultItem,
    SearchResultOfFireteamResponse,
    SearchResultOfFireteamSummary,
    SearchResultOfGroupBan,
    SearchResultOfGroupMember,
    SearchResultOfGroupMemberApplication,
    SearchResultOfGroupMembership,
    SearchResultOfGroupPotentialMembership,
    SearchResultOfGroupV2Card,
    SearchResultOfPostResponse,
    SearchResultOfTrendingEntry,
    SingleComponentResponseOfDestinyCharacterActivitiesComponent,
    SingleComponentResponseOfDestinyCharacterComponent,
    SingleComponentResponseOfDestinyCharacterProgressionComponent,
    SingleComponentResponseOfDestinyCharacterRecordsComponent,
    SingleComponentResponseOfDestinyCharacterRenderComponent,
    SingleComponentResponseOfDestinyCollectiblesComponent,
    SingleComponentResponseOfDestinyCurrenciesComponent,
    SingleComponentResponseOfDestinyInventoryComponent,
    SingleComponentResponseOfDestinyItemComponent,
    SingleComponentResponseOfDestinyItemInstanceComponent,
    SingleComponentResponseOfDestinyItemObjectivesComponent,
    SingleComponentResponseOfDestinyItemPerksComponent,
    SingleComponentResponseOfDestinyItemPlugObjectivesComponent,
    SingleComponentResponseOfDestinyItemRenderComponent,
    SingleComponentResponseOfDestinyItemReusablePlugsComponent,
    SingleComponentResponseOfDestinyItemSocketsComponent,
    SingleComponentResponseOfDestinyItemStatsComponent,
    SingleComponentResponseOfDestinyItemTalentGridComponent,
    SingleComponentResponseOfDestinyKiosksComponent,
    SingleComponentResponseOfDestinyMetricsComponent,
    SingleComponentResponseOfDestinyPlatformSilverComponent,
    SingleComponentResponseOfDestinyPlugSetsComponent,
    SingleComponentResponseOfDestinyPresentationNodesComponent,
    SingleComponentResponseOfDestinyProfileCollectiblesComponent,
    SingleComponentResponseOfDestinyProfileComponent,
    SingleComponentResponseOfDestinyProfileProgressionComponent,
    SingleComponentResponseOfDestinyProfileRecordsComponent,
    SingleComponentResponseOfDestinyProfileTransitoryComponent,
    SingleComponentResponseOfDestinyStringVariablesComponent,
    SingleComponentResponseOfDestinyVendorCategoriesComponent,
    SingleComponentResponseOfDestinyVendorComponent,
    SingleComponentResponseOfDestinyVendorGroupComponent,
    SingleComponentResponseOfDestinyVendorReceiptsComponent,
    StreamInfo,
)
from bungio.models.bungie.queries import PagedQuery, SearchResult
from bungio.models.bungie.social.friends import (
    BungieFriend,
    BungieFriendListResponse,
    BungieFriendRequestListResponse,
    FriendRelationshipState,
    PlatformFriend,
    PlatformFriendResponse,
    PlatformFriendType,
    PresenceOnlineStateFlags,
    PresenceStatus,
)
from bungio.models.bungie.tags.models.contracts import TagResponse
from bungio.models.bungie.tokens import (
    BungieRewardDisplay,
    CollectibleDefinitions,
    PartnerOfferClaimRequest,
    PartnerOfferHistoryResponse,
    PartnerOfferSkuHistoryResponse,
    RewardAvailabilityModel,
    RewardDisplayProperties,
    UserRewardAvailabilityModel,
)
from bungio.models.bungie.trending import (
    TrendingCategories,
    TrendingCategory,
    TrendingDetail,
    TrendingEntry,
    TrendingEntryCommunityCreation,
    TrendingEntryDestinyActivity,
    TrendingEntryDestinyItem,
    TrendingEntryDestinyRitual,
    TrendingEntryNews,
    TrendingEntrySupportArticle,
    TrendingEntryType,
)
from bungio.models.bungie.user import (
    CrossSaveUserMembership,
    EmailOptInDefinition,
    EMailSettingLocalization,
    EmailSettings,
    EMailSettingSubscriptionLocalization,
    EmailSubscriptionDefinition,
    EmailViewDefinition,
    EmailViewDefinitionSetting,
    ExactSearchRequest,
    GeneralUser,
    HardLinkedUserMembership,
    OptInFlags,
    UserInfoCard,
    UserMembership,
    UserMembershipData,
    UserSearchPrefixRequest,
    UserSearchResponse,
    UserSearchResponseDetail,
    UserToUserContext,
)
from bungio.models.bungie.user.models import GetCredentialTypesForAccountResponse



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import TYPE_CHECKING, Optional

from bungio.models.base import BaseModel, custom_define, custom_field

if TYPE_CHECKING:
    from bungio.models import (
        DestinyActivityDefinition,
        DestinyInventoryItemDefinition,
        DestinyLocationDefinition,
        DestinyObjectiveDefinition,
    )


@custom_define()
class DestinyEnvironmentLocationMapping(BaseModel):
    """
    _No description given by bungie._

    Tip: Manifest Information
        This model has some attributes which can be filled with additional information found in the manifest (`manifest_...`).
        Without additional work, these attributes will be `None`, since they require additional requests and database lookups.

        To fill the manifest dependent attributes, either:

        - Run `await ThisClass.fetch_manifest_information()`, see [here](/API Reference/Models/base)
        - Set `Client.always_return_manifest_information` to `True`, see [here](/API Reference/client)

    Attributes:
        activation_source: A hint that the UI uses to figure out how this location is activated by the player.
        activity_hash: If this is populated, this is the activity you have to be playing in order to see this location appear because of this mapping. (theoretically, a location can have multiple mappings, and some might require you to be in a specific activity when others don't)
        item_hash: If this is populated, it is the item that you must possess for this location to be active because of this mapping. (theoretically, a location can have multiple mappings, and some might require an item while others don't)
        location_hash: The location that is revealed on the director by this mapping.
        objective_hash: If this is populated, this is an objective related to the location.
        manifest_activity_hash: Manifest information for `activity_hash`
        manifest_item_hash: Manifest information for `item_hash`
        manifest_location_hash: Manifest information for `location_hash`
        manifest_objective_hash: Manifest information for `objective_hash`
    """

    activation_source: str = custom_field()
    activity_hash: int = custom_field()
    item_hash: int = custom_field()
    location_hash: int = custom_field()
    objective_hash: int = custom_field()
    manifest_activity_hash: Optional["DestinyActivityDefinition"] = custom_field(default=None)
    manifest_item_hash: Optional["DestinyInventoryItemDefinition"] = custom_field(default=None)
    manifest_location_hash: Optional["DestinyLocationDefinition"] = custom_field(default=None)
    manifest_objective_hash: Optional["DestinyObjectiveDefinition"] = custom_field(default=None)



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from datetime import datetime
from typing import TYPE_CHECKING, Union

from bungio.models.base import (
    BaseEnum,
    BaseFlagEnum,
    BaseModel,
    custom_define,
    custom_field,
)
from bungio.models.mixins import DestinyClanMixin, DestinyUserMixin
from bungio.utils import enum_converter

if TYPE_CHECKING:
    from bungio.models import (
        BungieMembershipType,
        DestinyProgression,
        IgnoreLength,
        PagedQuery,
        UserInfoCard,
        UserMembership,
    )


@custom_define()
class GroupUserInfoCard(BaseModel, DestinyUserMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        applicable_membership_types: The list of Membership Types indicating the platforms on which this Membership can be used.  Not in Cross Save = its original membership type. Cross Save Primary = Any membership types it is overridding, and its original membership type Cross Save Overridden = Empty list
        bungie_global_display_name: The bungie global display name, if set.
        bungie_global_display_name_code: The bungie global display name code, if set.
        cross_save_override: If there is a cross save override in effect, this value will tell you the type that is overridding this one.
        display_name: Display Name the player has chosen for themselves. The display name is optional when the data type is used as input to a platform API.
        icon_path: URL the Icon if available.
        is_public: If True, this is a public user membership.
        last_seen_display_name: This will be the display name the clan server last saw the user as. If the account is an active cross save override, this will be the display name to use. Otherwise, this will match the displayName property.
        last_seen_display_name_type: The platform of the LastSeenDisplayName
        membership_id: Membership ID as they user is known in the Accounts service
        membership_type: Type of the membership. Not necessarily the native type.
        supplemental_display_name: A platform specific additional display name - ex: psn Real Name, bnet Unique Name, etc.
    """

    applicable_membership_types: list[Union["BungieMembershipType", int]] = custom_field(
        converter=enum_converter("BungieMembershipType")
    )
    bungie_global_display_name: str = custom_field()
    bungie_global_display_name_code: int = custom_field()
    cross_save_override: Union["BungieMembershipType", int] = custom_field(
        converter=enum_converter("BungieMembershipType")
    )
    display_name: str = custom_field()
    icon_path: str = custom_field()
    is_public: bool = custom_field()
    last_seen_display_name: str = custom_field()
    last_seen_display_name_type: Union["BungieMembershipType", int] = custom_field(
        converter=enum_converter("BungieMembershipType")
    )
    membership_id: int = custom_field()
    membership_type: Union["BungieMembershipType", int] = custom_field(converter=enum_converter("BungieMembershipType"))
    supplemental_display_name: str = custom_field()


@custom_define()
class GroupResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        alliance_status: _No description given by bungie._
        allied_ids: _No description given by bungie._
        current_user_member_map: This property will be populated if the authenticated user is a member of the group. Note that because of account linking, a user can sometimes be part of a clan more than once. As such, this returns the highest member type available.
        current_user_memberships_inactive_for_destiny: A convenience property that indicates if every membership you (the current user) have that is a part of this group are part of an account that is considered inactive - for example, overridden accounts in Cross Save.
        current_user_potential_member_map: This property will be populated if the authenticated user is an applicant or has an outstanding invitation to join. Note that because of account linking, a user can sometimes be part of a clan more than once.
        detail: _No description given by bungie._
        founder: _No description given by bungie._
        group_join_invite_count: _No description given by bungie._
        parent_group: _No description given by bungie._
    """

    alliance_status: Union["GroupAllianceStatus", int] = custom_field(converter=enum_converter("GroupAllianceStatus"))
    allied_ids: list[int] = custom_field(metadata={"type": """list[int]"""})
    current_user_member_map: dict[Union["BungieMembershipType", int], "GroupMember"] = custom_field(
        metadata={"type": """dict[BungieMembershipType, GroupMember]"""}
    )
    current_user_memberships_inactive_for_destiny: bool = custom_field()
    current_user_potential_member_map: dict[Union["BungieMembershipType", int], "GroupPotentialMember"] = custom_field(
        metadata={"type": """dict[BungieMembershipType, GroupPotentialMember]"""}
    )
    detail: "GroupV2" = custom_field()
    founder: "GroupMember" = custom_field()
    group_join_invite_count: int = custom_field()
    parent_group: "GroupV2" = custom_field()


@custom_define()
class GroupV2(BaseModel, DestinyClanMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        about: _No description given by bungie._
        allow_chat: _No description given by bungie._
        avatar_image_index: _No description given by bungie._
        avatar_path: _No description given by bungie._
        ban_expire_date: _No description given by bungie._
        banner_path: _No description given by bungie._
        chat_security: _No description given by bungie._
        clan_info: _No description given by bungie._
        conversation_id: _No description given by bungie._
        creation_date: _No description given by bungie._
        default_publicity: _No description given by bungie._
        enable_invitation_messaging_for_admins: _No description given by bungie._
        features: _No description given by bungie._
        group_id: _No description given by bungie._
        group_type: _No description given by bungie._
        homepage: _No description given by bungie._
        is_default_post_public: _No description given by bungie._
        is_public: _No description given by bungie._
        is_public_topic_admin_only: _No description given by bungie._
        locale: _No description given by bungie._
        member_count: _No description given by bungie._
        membership_id_created: _No description given by bungie._
        membership_option: _No description given by bungie._
        modification_date: _No description given by bungie._
        motto: _No description given by bungie._
        name: _No description given by bungie._
        tags: _No description given by bungie._
        theme: _No description given by bungie._
    """

    about: str = custom_field()
    allow_chat: bool = custom_field()
    avatar_image_index: int = custom_field()
    avatar_path: str = custom_field()
    ban_expire_date: datetime = custom_field()
    banner_path: str = custom_field()
    chat_security: Union["ChatSecuritySetting", int] = custom_field(converter=enum_converter("ChatSecuritySetting"))
    clan_info: "GroupV2ClanInfoAndInvestment" = custom_field()
    conversation_id: int = custom_field()
    creation_date: datetime = custom_field()
    default_publicity: Union["GroupPostPublicity", int] = custom_field(converter=enum_converter("GroupPostPublicity"))
    enable_invitation_messaging_for_admins: bool = custom_field()
    features: "GroupFeatures" = custom_field()
    group_id: int = custom_field()
    group_type: Union["GroupType", int] = custom_field(converter=enum_converter("GroupType"))
    homepage: Union["GroupHomepage", int] = custom_field(converter=enum_converter("GroupHomepage"))
    is_default_post_public: bool = custom_field()
    is_public: bool = custom_field()
    is_public_topic_admin_only: bool = custom_field()
    locale: str = custom_field()
    member_count: int = custom_field()
    membership_id_created: int = custom_field()
    membership_option: Union["MembershipOption", int] = custom_field(converter=enum_converter("MembershipOption"))
    modification_date: datetime = custom_field()
    motto: str = custom_field()
    name: str = custom_field()
    tags: list[str] = custom_field(metadata={"type": """list[str]"""})
    theme: str = custom_field()


class GroupType(BaseEnum):
    """
    _No description given by bungie._
    """

    GENERAL = 0
    """_No description given by bungie._ """
    CLAN = 1
    """_No description given by bungie._ """


class ChatSecuritySetting(BaseEnum):
    """
    _No description given by bungie._
    """

    GROUP = 0
    """_No description given by bungie._ """
    ADMINS = 1
    """_No description given by bungie._ """


class GroupHomepage(BaseEnum):
    """
    _No description given by bungie._
    """

    WALL = 0
    """_No description given by bungie._ """
    FORUM = 1
    """_No description given by bungie._ """
    ALLIANCE_FORUM = 2
    """_No description given by bungie._ """


class MembershipOption(BaseEnum):
    """
    _No description given by bungie._
    """

    REVIEWED = 0
    """_No description given by bungie._ """
    OPEN = 1
    """_No description given by bungie._ """
    CLOSED = 2
    """_No description given by bungie._ """


class GroupPostPublicity(BaseEnum):
    """
    _No description given by bungie._
    """

    PUBLIC = 0
    """_No description given by bungie._ """
    ALLIANCE = 1
    """_No description given by bungie._ """
    PRIVATE = 2
    """_No description given by bungie._ """


@custom_define()
class GroupFeatures(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        capabilities: _No description given by bungie._
        host_guided_game_permission_override: Minimum Member Level allowed to host guided games Always Allowed: Founder, Acting Founder, Admin Allowed Overrides: None, Member, Beginner Default is Member for clans, None for groups, although this means nothing for groups.
        invite_permission_override: Minimum Member Level allowed to invite new members to group Always Allowed: Founder, Acting Founder True means admins have this power, false means they don't Default is false for clans, true for groups.
        join_level: Level to join a member at when accepting an invite, application, or joining an open clan Default is Beginner.
        maximum_members: _No description given by bungie._
        maximum_memberships_of_group_type: Maximum number of groups of this type a typical membership may join. For example, a user may join about 50 General groups with their Bungie.net account. They may join one clan per Destiny membership.
        membership_types: _No description given by bungie._
        update_banner_permission_override: Minimum Member Level allowed to update banner Always Allowed: Founder, Acting Founder True means admins have this power, false means they don't Default is false for clans, true for groups.
        update_culture_permission_override: Minimum Member Level allowed to update group culture Always Allowed: Founder, Acting Founder True means admins have this power, false means they don't Default is false for clans, true for groups.
    """

    capabilities: Union["Capabilities", int] = custom_field(converter=enum_converter("Capabilities"))
    host_guided_game_permission_override: Union["HostGuidedGamesPermissionLevel", int] = custom_field(
        converter=enum_converter("HostGuidedGamesPermissionLevel")
    )
    invite_permission_override: bool = custom_field()
    join_level: Union["RuntimeGroupMemberType", int] = custom_field(converter=enum_converter("RuntimeGroupMemberType"))
    maximum_members: int = custom_field()
    maximum_memberships_of_group_type: int = custom_field()
    membership_types: list[Union["BungieMembershipType", int]] = custom_field(
        converter=enum_converter("BungieMembershipType")
    )
    update_banner_permission_override: bool = custom_field()
    update_culture_permission_override: bool = custom_field()


class Capabilities(BaseFlagEnum):
    """
    _No description given by bungie._
    """

    NONE = 0
    """_No description given by bungie._ """
    LEADERBOARDS = 1
    """_No description given by bungie._ """
    CALLSIGN = 2
    """_No description given by bungie._ """
    OPTIONAL_CONVERSATIONS = 4
    """_No description given by bungie._ """
    CLAN_BANNER = 8
    """_No description given by bungie._ """
    D2_INVESTMENT_DATA = 16
    """_No description given by bungie._ """
    TAGS = 32
    """_No description given by bungie._ """
    ALLIANCES = 64
    """_No description given by bungie._ """


class HostGuidedGamesPermissionLevel(BaseEnum):
    """
    Used for setting the guided game permission level override (admins and founders can always host guided games).
    """

    NONE = 0
    """_No description given by bungie._ """
    BEGINNER = 1
    """_No description given by bungie._ """
    MEMBER = 2
    """_No description given by bungie._ """


class RuntimeGroupMemberType(BaseEnum):
    """
    The member levels used by all V2 Groups API. Individual group types use their own mappings in their native storage (general uses BnetDbGroupMemberType and D2 clans use ClanMemberLevel), but they are all translated to this in the runtime api. These runtime values should NEVER be stored anywhere, so the values can be changed as necessary.
    """

    NONE = 0
    """_No description given by bungie._ """
    BEGINNER = 1
    """_No description given by bungie._ """
    MEMBER = 2
    """_No description given by bungie._ """
    ADMIN = 3
    """_No description given by bungie._ """
    ACTING_FOUNDER = 4
    """_No description given by bungie._ """
    FOUNDER = 5
    """_No description given by bungie._ """


@custom_define()
class GroupV2ClanInfo(BaseModel):
    """
    This contract contains clan-specific group information. It does not include any investment data.

    None
    Attributes:
        clan_banner_data: _No description given by bungie._
        clan_callsign: _No description given by bungie._
    """

    clan_banner_data: "ClanBanner" = custom_field()
    clan_callsign: str = custom_field()


@custom_define()
class ClanBanner(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        decal_background_color_id: _No description given by bungie._
        decal_color_id: _No description given by bungie._
        decal_id: _No description given by bungie._
        gonfalon_color_id: _No description given by bungie._
        gonfalon_detail_color_id: _No description given by bungie._
        gonfalon_detail_id: _No description given by bungie._
        gonfalon_id: _No description given by bungie._
    """

    decal_background_color_id: int = custom_field()
    decal_color_id: int = custom_field()
    decal_id: int = custom_field()
    gonfalon_color_id: int = custom_field()
    gonfalon_detail_color_id: int = custom_field()
    gonfalon_detail_id: int = custom_field()
    gonfalon_id: int = custom_field()


@custom_define()
class GroupV2ClanInfoAndInvestment(BaseModel):
    """
    The same as GroupV2ClanInfo, but includes any investment data.

    None
    Attributes:
        clan_banner_data: _No description given by bungie._
        clan_callsign: _No description given by bungie._
        d2_clan_progressions: _No description given by bungie._
    """

    clan_banner_data: "ClanBanner" = custom_field()
    clan_callsign: str = custom_field()
    d2_clan_progressions: dict[int, "DestinyProgression"] = custom_field(
        metadata={"type": """dict[int, DestinyProgression]"""}
    )


@custom_define()
class GroupUserBase(BaseModel, DestinyClanMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        bungie_net_user_info: _No description given by bungie._
        destiny_user_info: _No description given by bungie._
        group_id: _No description given by bungie._
        join_date: _No description given by bungie._
    """

    bungie_net_user_info: "UserInfoCard" = custom_field()
    destiny_user_info: "GroupUserInfoCard" = custom_field()
    group_id: int = custom_field()
    join_date: datetime = custom_field()


@custom_define()
class GroupMember(BaseModel, DestinyClanMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        bungie_net_user_info: _No description given by bungie._
        destiny_user_info: _No description given by bungie._
        group_id: _No description given by bungie._
        is_online: _No description given by bungie._
        join_date: _No description given by bungie._
        last_online_status_change: _No description given by bungie._
        member_type: _No description given by bungie._
    """

    bungie_net_user_info: "UserInfoCard" = custom_field()
    destiny_user_info: "GroupUserInfoCard" = custom_field()
    group_id: int = custom_field()
    is_online: bool = custom_field()
    join_date: datetime = custom_field()
    last_online_status_change: int = custom_field()
    member_type: Union["RuntimeGroupMemberType", int] = custom_field(converter=enum_converter("RuntimeGroupMemberType"))


class GroupAllianceStatus(BaseEnum):
    """
    _No description given by bungie._
    """

    UNALLIED = 0
    """_No description given by bungie._ """
    PARENT = 1
    """_No description given by bungie._ """
    CHILD = 2
    """_No description given by bungie._ """


@custom_define()
class GroupPotentialMember(BaseModel, DestinyClanMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        bungie_net_user_info: _No description given by bungie._
        destiny_user_info: _No description given by bungie._
        group_id: _No description given by bungie._
        join_date: _No description given by bungie._
        potential_status: _No description given by bungie._
    """

    bungie_net_user_info: "UserInfoCard" = custom_field()
    destiny_user_info: "GroupUserInfoCard" = custom_field()
    group_id: int = custom_field()
    join_date: datetime = custom_field()
    potential_status: Union["GroupPotentialMemberStatus", int] = custom_field(
        converter=enum_converter("GroupPotentialMemberStatus")
    )


class GroupPotentialMemberStatus(BaseEnum):
    """
    _No description given by bungie._
    """

    NONE = 0
    """_No description given by bungie._ """
    APPLICANT = 1
    """_No description given by bungie._ """
    INVITEE = 2
    """_No description given by bungie._ """


class GroupDateRange(BaseEnum):
    """
    _No description given by bungie._
    """

    ALL = 0
    """_No description given by bungie._ """
    PAST_DAY = 1
    """_No description given by bungie._ """
    PAST_WEEK = 2
    """_No description given by bungie._ """
    PAST_MONTH = 3
    """_No description given by bungie._ """
    PAST_YEAR = 4
    """_No description given by bungie._ """


@custom_define()
class GroupV2Card(BaseModel, DestinyClanMixin):
    """
    A small infocard of group information, usually used for when a list of groups are returned

    None
    Attributes:
        about: _No description given by bungie._
        avatar_path: _No description given by bungie._
        capabilities: _No description given by bungie._
        clan_info: _No description given by bungie._
        creation_date: _No description given by bungie._
        group_id: _No description given by bungie._
        group_type: _No description given by bungie._
        locale: _No description given by bungie._
        member_count: _No description given by bungie._
        membership_option: _No description given by bungie._
        motto: _No description given by bungie._
        name: _No description given by bungie._
        theme: _No description given by bungie._
    """

    about: str = custom_field()
    avatar_path: str = custom_field()
    capabilities: Union["Capabilities", int] = custom_field(converter=enum_converter("Capabilities"))
    clan_info: "GroupV2ClanInfo" = custom_field()
    creation_date: datetime = custom_field()
    group_id: int = custom_field()
    group_type: Union["GroupType", int] = custom_field(converter=enum_converter("GroupType"))
    locale: str = custom_field()
    member_count: int = custom_field()
    membership_option: Union["MembershipOption", int] = custom_field(converter=enum_converter("MembershipOption"))
    motto: str = custom_field()
    name: str = custom_field()
    theme: str = custom_field()


@custom_define()
class GroupSearchResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        has_more: _No description given by bungie._
        query: _No description given by bungie._
        replacement_continuation_token: _No description given by bungie._
        results: _No description given by bungie._
        total_results: _No description given by bungie._
        use_total_results: If useTotalResults is true, then totalResults represents an accurate count. If False, it does not, and may be estimated/only the size of the current page. Either way, you should probably always only trust hasMore. This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.
    """

    has_more: bool = custom_field()
    query: "PagedQuery" = custom_field()
    replacement_continuation_token: str = custom_field()
    results: list["GroupV2Card"] = custom_field(metadata={"type": """list[GroupV2Card]"""})
    total_results: int = custom_field()
    use_total_results: bool = custom_field()


@custom_define()
class OverwrittenGroupQuery(BaseModel):
    """
    NOTE: GroupQuery, as of Destiny 2, has essentially two totally different and incompatible "modes". If you are querying for a group, you can pass any of the properties below. If you are querying for a Clan, you MUST NOT pass any of the following properties (they must be null or undefined in your request, not just empty string/default values): - groupMemberCountFilter - localeFilter - tagText If you pass these, you will get a useless InvalidParameters error.

    None
    Attributes:
        creation_date: _No description given by bungie._
        current_page: _No description given by bungie._
        group_member_count_filter: _No description given by bungie._
        group_type: _No description given by bungie._
        items_per_page: _No description given by bungie._
        locale_filter: _No description given by bungie._
        name: _No description given by bungie._
        request_continuation_token: _No description given by bungie._
        sort_by: _No description given by bungie._
        tag_text: _No description given by bungie._
    """

    creation_date: Union["GroupDateRange", int] = custom_field(converter=enum_converter("GroupDateRange"))
    current_page: int = custom_field()
    group_member_count_filter: int = custom_field()
    group_type: Union["GroupType", int] = custom_field(converter=enum_converter("GroupType"))
    items_per_page: int = custom_field()
    locale_filter: str = custom_field()
    name: str = custom_field()
    request_continuation_token: str = custom_field()
    sort_by: Union["GroupSortBy", int] = custom_field(converter=enum_converter("GroupSortBy"))
    tag_text: str = custom_field()


class GroupSortBy(BaseEnum):
    """
    _No description given by bungie._
    """

    NAME = 0
    """_No description given by bungie._ """
    DATE = 1
    """_No description given by bungie._ """
    POPULARITY = 2
    """_No description given by bungie._ """
    ID = 3
    """_No description given by bungie._ """


class GroupMemberCountFilter(BaseEnum):
    """
    _No description given by bungie._
    """

    ALL = 0
    """_No description given by bungie._ """
    ONE_TO_TEN = 1
    """_No description given by bungie._ """
    ELEVEN_TO_ONE_HUNDRED = 2
    """_No description given by bungie._ """
    GREATER_THAN_ONE_HUNDRED = 3
    """_No description given by bungie._ """


@custom_define()
class GroupNameSearchRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        group_name: _No description given by bungie._
        group_type: _No description given by bungie._
    """

    group_name: str = custom_field()
    group_type: Union["GroupType", int] = custom_field(converter=enum_converter("GroupType"))


@custom_define()
class GroupOptionalConversation(BaseModel, DestinyClanMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        chat_enabled: _No description given by bungie._
        chat_name: _No description given by bungie._
        chat_security: _No description given by bungie._
        conversation_id: _No description given by bungie._
        group_id: _No description given by bungie._
    """

    chat_enabled: bool = custom_field()
    chat_name: str = custom_field()
    chat_security: Union["ChatSecuritySetting", int] = custom_field(converter=enum_converter("ChatSecuritySetting"))
    conversation_id: int = custom_field()
    group_id: int = custom_field()


@custom_define()
class GroupEditAction(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        about: _No description given by bungie._
        allow_chat: _No description given by bungie._
        avatar_image_index: _No description given by bungie._
        callsign: _No description given by bungie._
        chat_security: _No description given by bungie._
        default_publicity: _No description given by bungie._
        enable_invitation_messaging_for_admins: _No description given by bungie._
        homepage: _No description given by bungie._
        is_public: _No description given by bungie._
        is_public_topic_admin_only: _No description given by bungie._
        locale: _No description given by bungie._
        membership_option: _No description given by bungie._
        motto: _No description given by bungie._
        name: _No description given by bungie._
        tags: _No description given by bungie._
        theme: _No description given by bungie._
    """

    about: str = custom_field()
    allow_chat: bool = custom_field()
    avatar_image_index: int = custom_field()
    callsign: str = custom_field()
    chat_security: int = custom_field()
    default_publicity: int = custom_field()
    enable_invitation_messaging_for_admins: bool = custom_field()
    homepage: int = custom_field()
    is_public: bool = custom_field()
    is_public_topic_admin_only: bool = custom_field()
    locale: str = custom_field()
    membership_option: int = custom_field()
    motto: str = custom_field()
    name: str = custom_field()
    tags: str = custom_field()
    theme: str = custom_field()


@custom_define()
class GroupOptionsEditAction(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        host_guided_game_permission_override: Minimum Member Level allowed to host guided games Always Allowed: Founder, Acting Founder, Admin Allowed Overrides: None, Member, Beginner Default is Member for clans, None for groups, although this means nothing for groups.
        invite_permission_override: Minimum Member Level allowed to invite new members to group Always Allowed: Founder, Acting Founder True means admins have this power, false means they don't Default is false for clans, true for groups.
        join_level: Level to join a member at when accepting an invite, application, or joining an open clan Default is Beginner.
        update_banner_permission_override: Minimum Member Level allowed to update banner Always Allowed: Founder, Acting Founder True means admins have this power, false means they don't Default is false for clans, true for groups.
        update_culture_permission_override: Minimum Member Level allowed to update group culture Always Allowed: Founder, Acting Founder True means admins have this power, false means they don't Default is false for clans, true for groups.
    """

    host_guided_game_permission_override: int = custom_field()
    invite_permission_override: bool = custom_field()
    join_level: int = custom_field()
    update_banner_permission_override: bool = custom_field()
    update_culture_permission_override: bool = custom_field()


@custom_define()
class GroupOptionalConversationAddRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        chat_name: _No description given by bungie._
        chat_security: _No description given by bungie._
    """

    chat_name: str = custom_field()
    chat_security: Union["ChatSecuritySetting", int] = custom_field(converter=enum_converter("ChatSecuritySetting"))


@custom_define()
class GroupOptionalConversationEditRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        chat_enabled: _No description given by bungie._
        chat_name: _No description given by bungie._
        chat_security: _No description given by bungie._
    """

    chat_enabled: bool = custom_field()
    chat_name: str = custom_field()
    chat_security: int = custom_field()


@custom_define()
class GroupMemberLeaveResult(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        group: _No description given by bungie._
        group_deleted: _No description given by bungie._
    """

    group: "GroupV2" = custom_field()
    group_deleted: bool = custom_field()


@custom_define()
class GroupBanRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        comment: _No description given by bungie._
        length: _No description given by bungie._
    """

    comment: str = custom_field()
    length: Union["IgnoreLength", int] = custom_field(converter=enum_converter("IgnoreLength"))


@custom_define()
class GroupBan(BaseModel, DestinyClanMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        bungie_net_user_info: _No description given by bungie._
        comment: _No description given by bungie._
        created_by: _No description given by bungie._
        date_banned: _No description given by bungie._
        date_expires: _No description given by bungie._
        destiny_user_info: _No description given by bungie._
        group_id: _No description given by bungie._
        last_modified_by: _No description given by bungie._
    """

    bungie_net_user_info: "UserInfoCard" = custom_field()
    comment: str = custom_field()
    created_by: "UserInfoCard" = custom_field()
    date_banned: datetime = custom_field()
    date_expires: datetime = custom_field()
    destiny_user_info: "GroupUserInfoCard" = custom_field()
    group_id: int = custom_field()
    last_modified_by: "UserInfoCard" = custom_field()


@custom_define()
class GroupMemberApplication(BaseModel, DestinyClanMixin):
    """
    _No description given by bungie._

    None
    Attributes:
        bungie_net_user_info: _No description given by bungie._
        creation_date: _No description given by bungie._
        destiny_user_info: _No description given by bungie._
        group_id: _No description given by bungie._
        request_message: _No description given by bungie._
        resolve_date: _No description given by bungie._
        resolve_message: _No description given by bungie._
        resolve_state: _No description given by bungie._
        resolved_by_membership_id: _No description given by bungie._
    """

    bungie_net_user_info: "UserInfoCard" = custom_field()
    creation_date: datetime = custom_field()
    destiny_user_info: "GroupUserInfoCard" = custom_field()
    group_id: int = custom_field()
    request_message: str = custom_field()
    resolve_date: datetime = custom_field()
    resolve_message: str = custom_field()
    resolve_state: Union["GroupApplicationResolveState", int] = custom_field(
        converter=enum_converter("GroupApplicationResolveState")
    )
    resolved_by_membership_id: int = custom_field()


class GroupApplicationResolveState(BaseEnum):
    """
    _No description given by bungie._
    """

    UNRESOLVED = 0
    """_No description given by bungie._ """
    ACCEPTED = 1
    """_No description given by bungie._ """
    DENIED = 2
    """_No description given by bungie._ """
    RESCINDED = 3
    """_No description given by bungie._ """


@custom_define()
class GroupApplicationRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        message: _No description given by bungie._
    """

    message: str = custom_field()


@custom_define()
class GroupApplicationListRequest(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        memberships: _No description given by bungie._
        message: _No description given by bungie._
    """

    memberships: list["UserMembership"] = custom_field(metadata={"type": """list[UserMembership]"""})
    message: str = custom_field()


class GroupsForMemberFilter(BaseEnum):
    """
    _No description given by bungie._
    """

    ALL = 0
    """_No description given by bungie._ """
    FOUNDED = 1
    """_No description given by bungie._ """
    NON_FOUNDED = 2
    """_No description given by bungie._ """


@custom_define()
class GroupMembershipBase(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        group: _No description given by bungie._
    """

    group: "GroupV2" = custom_field()


@custom_define()
class GroupMembership(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        group: _No description given by bungie._
        member: _No description given by bungie._
    """

    group: "GroupV2" = custom_field()
    member: "GroupMember" = custom_field()


@custom_define()
class GroupMembershipSearchResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        has_more: _No description given by bungie._
        query: _No description given by bungie._
        replacement_continuation_token: _No description given by bungie._
        results: _No description given by bungie._
        total_results: _No description given by bungie._
        use_total_results: If useTotalResults is true, then totalResults represents an accurate count. If False, it does not, and may be estimated/only the size of the current page. Either way, you should probably always only trust hasMore. This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.
    """

    has_more: bool = custom_field()
    query: "PagedQuery" = custom_field()
    replacement_continuation_token: str = custom_field()
    results: list["GroupMembership"] = custom_field(metadata={"type": """list[GroupMembership]"""})
    total_results: int = custom_field()
    use_total_results: bool = custom_field()


@custom_define()
class GetGroupsForMemberResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        are_all_memberships_inactive: A convenience property that indicates if every membership this user has that is a part of this group are part of an account that is considered inactive - for example, overridden accounts in Cross Save.  The key is the Group ID for the group being checked, and the value is true if the users' memberships for that group are all inactive.
        has_more: _No description given by bungie._
        query: _No description given by bungie._
        replacement_continuation_token: _No description given by bungie._
        results: _No description given by bungie._
        total_results: _No description given by bungie._
        use_total_results: If useTotalResults is true, then totalResults represents an accurate count. If False, it does not, and may be estimated/only the size of the current page. Either way, you should probably always only trust hasMore. This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.
    """

    are_all_memberships_inactive: dict[int, bool] = custom_field(metadata={"type": """dict[int, bool]"""})
    has_more: bool = custom_field()
    query: "PagedQuery" = custom_field()
    replacement_continuation_token: str = custom_field()
    results: list["GroupMembership"] = custom_field(metadata={"type": """list[GroupMembership]"""})
    total_results: int = custom_field()
    use_total_results: bool = custom_field()


@custom_define()
class GroupPotentialMembership(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        group: _No description given by bungie._
        member: _No description given by bungie._
    """

    group: "GroupV2" = custom_field()
    member: "GroupPotentialMember" = custom_field()


@custom_define()
class GroupPotentialMembershipSearchResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        has_more: _No description given by bungie._
        query: _No description given by bungie._
        replacement_continuation_token: _No description given by bungie._
        results: _No description given by bungie._
        total_results: _No description given by bungie._
        use_total_results: If useTotalResults is true, then totalResults represents an accurate count. If False, it does not, and may be estimated/only the size of the current page. Either way, you should probably always only trust hasMore. This is a long-held historical throwback to when we used to do paging with known total results. Those queries toasted our database, and we were left to hastily alter our endpoints and create backward- compatible shims, of which useTotalResults is one.
    """

    has_more: bool = custom_field()
    query: "PagedQuery" = custom_field()
    replacement_continuation_token: str = custom_field()
    results: list["GroupPotentialMembership"] = custom_field(metadata={"type": """list[GroupPotentialMembership]"""})
    total_results: int = custom_field()
    use_total_results: bool = custom_field()


@custom_define()
class GroupApplicationResponse(BaseModel):
    """
    _No description given by bungie._

    None
    Attributes:
        resolution: _No description given by bungie._
    """

    resolution: Union["GroupApplicationResolveState", int] = custom_field(
        converter=enum_converter("GroupApplicationResolveState")
    )



# DO NOT CHANGE ANY CODE BELOW
# This file is generated automatically by `generate_api_schema.py` and will be overwritten
# Instead, change functions / models by subclassing them in the `./overwrites/` folder. They will be used instead.

from typing import Union

from bungio.models.base import BaseEnum, BaseModel, custom_define, custom_field
from bungio.utils import enum_converter


@custom_define()
class ComponentResponse(BaseModel):
    """
    The base class for any component-returning object that may need to indicate information about the state of the component being returned.

    None
    Attributes:
        disabled: If true, this component is disabled.
        privacy: _No description given by bungie._
    """

    disabled: bool = custom_field()
    privacy: Union["ComponentPrivacySetting", int] = custom_field(converter=enum_converter("ComponentPrivacySetting"))


class ComponentPrivacySetting(BaseEnum):
    """
    A set of flags for reason(s) why the component populated in the way that it did. Inspect the individual flags for the reasons.
    """

    NONE = 0
    """_No description given by bungie._ """
    PUBLIC = 1
    """_No description given by bungie._ """
    PRIVATE = 2
    """_No description given by bungie._ """



import logging
import os
from importlib.metadata import version as _v

__all__ = ("ROOT_DIR", "BASE_ROUTE", "LOGGER_NAME", "DEFAULT_LOGGER", "__version__", "__repo_url__", "__author__")

ROOT_DIR = os.path.split(os.path.dirname(os.path.abspath(__file__)))[0]
BASE_ROUTE = "https://www.bungie.net/Platform"
LOGGER_NAME = "BungIO"
DEFAULT_LOGGER = logging.getLogger(LOGGER_NAME)
DEFAULT_LOGGER.setLevel(logging.WARNING)

try:
    __version__ = _v("bungio")
except Exception:
    __version__ = "0.0.0"
__repo_url__ = "https://github.com/Kigstn/BungIO"
__author__ = "Kigstn"
